@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.03';
+$VERSION = '1.04';
 
 #----------------------------------------------------------------------------
 
@@ -594,6 +594,10 @@ sub _write_basics {
             warn "Missing file: $source\n";
         }
     }
+
+    # wget
+    my $cmd = sprintf "wget -O %s/sponsors.json http://iheart.cpantesters.org/home/sponsors?images=1 2>/dev/null", $directory;
+    system($cmd);
 }
 
 =item * _write_index
@@ -960,7 +964,7 @@ sub _build_noreports {
             my @dt = localtime($_->{released});
             $_->{datetime} = sprintf "%04d-%02d-%02d", $dt[5]+1900,$dt[4]+1,$dt[3];
         }
-        $tvars = { rows => \@dists, rowcount => scalar(@dists), template => 'noreports', osnames => \@osnames, ostitle => $os->{ostitle} };
+        $tvars = { rows => \@dists, rowcount => scalar(@dists), template => 'noreports', osnames => \@osnames, ostitle => $os->{ostitle}, osname => $os->{osname} };
         $self->_writepage('noreports/'.$os->{osname},$tvars);
     }
 
